import java.awt.*;
import java.io.*;
import javabook.*;
/**
  * Funktionskomponent<BR>
  * Generaliseret Filemanager for modelkomponenten<BR>
  * Klassen anvendes til at gemme og hente modelkomponenten,
  * der udgr et object, som kan serialiseres
  *
  * @version     Nov 2001
  * @author      Bjrk Busch
*/

public	class FileManager
{

    // Denne metode justerer filename s det f navnet data, hvis der ikke er angivet et navn
    // og extention .dat, hvis der ikke er angivet et extention
		private static String setKorrektFileName (String fileName)
		{
				if ((fileName.length() == 0) || (fileName.indexOf('.') == 0))
						fileName = "data";
				else if	(fileName.indexOf('.') > 0)
						fileName = fileName.substring(0,fileName.indexOf('.'));
				fileName = fileName+".dat";
				return	(fileName);
		}


  /**
   * Klasse-metode, der anvendes til at gemme model-komponenten som eet objekt p disk
   *
   * @param   directoryName    Katalog/mappe hvor modelkomponent skal gemmes
   * @param   fileName         Filnavn hvor modelkomponent skal gemmes
   * @param   model            Objekt med modelkomponenten
   * @exception   IOException  
   */
		public static void saveModel (String directoryName, String fileName, Object model) throws IOException
		{
				try
				{
						File	outFile	=	new	File(directoryName+setKorrektFileName(fileName));
						FileOutputStream	outFileStream	=	new	FileOutputStream(outFile);
						ObjectOutputStream	outObjectStream	=	new	ObjectOutputStream(outFileStream);
						
						outObjectStream.writeObject(model);

						outObjectStream.close();

				}
				catch (FileNotFoundException	e)
				{
			      System.out.println("Filen "+fileName+" eksisterer ikke");
			      throw e;
				}	
				catch (IOException	e)
				{
			      System.out.println("Generel I/O exception");
			      throw e;
				}	
				finally
				{
						// udfres selvom fejl	
				}	
		}


  /**
   * Klasse-metode, der anvendes til at indlste en modelkomponent gemt som eet objekt
   *
   * @param   directoryName    Katalog/mappe hvor modelkomponent skal gemmes
   * @param   fileName         Filnavn hvor modelkomponent skal gemmes
   * @return     Object    Objekt med modelkomponent
   * @exception   IOException  
   * @exception   ClassNotFoundException  
   */
		public static Object loadModel (String directoryName, String fileName) throws IOException, ClassNotFoundException

		{
				Object	model = null;
				try
				{
						File	inFile	=	new	File(directoryName+setKorrektFileName(fileName));
						FileInputStream	inFileStream	=	new	FileInputStream(inFile);
						ObjectInputStream	inObjectStream	=	new	ObjectInputStream(inFileStream);
						
						model = inObjectStream.readObject();

						inObjectStream.close();

				}
				catch (ClassNotFoundException	e)
				{
			      System.out.println("Filen "+fileName+" indeholder ikke java-objekter");
			      throw e;
				}	
				catch (FileNotFoundException	e)
				{
			      System.out.println("Filen "+fileName+" eksisterer ikke");
			      throw e;
				}	
				catch (EOFException	e)
				{
			      System.out.println("Fejl: der kan ikke lses forbi slutning af filen");
			      throw e;
				}	
				catch (IOException	e)
				{
			      System.out.println("Generel I/O exception");
			      throw e;
				}	
				finally
				{
						// udfres selvom fejl	
				}	
				return	(model);
		}

}