import java.io.*;  
import java.util.*;  
import java.sql.*;  
/**  
  * @version  November 2002
  * @author   Bjrk Busch
*/  

public class Vare implements Serializable
{  
  public  static  int      TILSTAND_AKTIV = 0;
  public  static  int      TILSTAND_UDGAAET = 1;

  private   String         betegnelse;
  private   String         enhed;
  private   double         aktuelSalgspris;
  private   Timestamp      iSortimentDato;
  private   Timestamp      udgaaetDato;
  private   Timestamp      sidstModtagetDato;
  private   double         sidstModtagetKvantum;
  private   double         sidstModtagetPris;
  private   double         totalModtagetKvantum;
  private   int            tilstand;

  private   double         totalVaresalgKvantum;  // sum af kvantum fra varesalgs objekter

  private   Vector         varesalgsVector = new Vector();


  // Constructor til at oprette object
  public   Vare ( String         betegnelse,
                  String         enhed,
                  double         aktuelSalgspris,
                  Timestamp      iSortimentDato )
  {
    this.betegnelse = betegnelse;
    this.enhed      = enhed;
    this.aktuelSalgspris = aktuelSalgspris;
    this.iSortimentDato = (Timestamp)iSortimentDato.clone();
    this.tilstand = TILSTAND_AKTIV;
  }

  //------- getmetoder
  public   String     getBetegnelse ( )            {  return  this.betegnelse;   }
  public   String     getEnhed ( )                 {  return  this.enhed;   }
  public   double     getAktuelSalgspris ( )       {  return  this.aktuelSalgspris;   }
  public   double     getSidstModtagetKvantum ( )  {  return  this.sidstModtagetKvantum;   }
  public   double     getSidstModtagetPris ( )     {  return  this.sidstModtagetPris;   }
  public   double     getTotalModtagetKvantum ( )  {  return  this.totalModtagetKvantum;   }
  public   int        getTilstand ( )              {  return  this.tilstand;   }
  public   double     getTotalVaresalgKvantum ( )  {  return  this.totalVaresalgKvantum;   }

  public   Timestamp  getISortimentDato ( )
  {  return  (Timestamp)this.iSortimentDato.clone();   }
  public   Timestamp   getUdgaaetDato ( )
  {
    if (this.udgaaetDato == null) return null;
    return (Timestamp)this.udgaaetDato.clone();
  }
  public   Timestamp   getSidstModtagetDato ( )
  {
    if (this.sidstModtagetDato == null) return null;
    return (Timestamp)this.sidstModtagetDato.clone();
  }

  public    String   toString()
  {
    return (""
            + ","+ getBetegnelse ( )
            + ","+ getEnhed ( )
            + ","+ getAktuelSalgspris ( )
            );
  }


  //------- ekstra metoder

  public   void   retStamdata ( String         betegnelse,
                                String         enhed,
                                double          aktuelSalgspris )
  {
    this.betegnelse = betegnelse;
    this.enhed      = enhed;
    this.aktuelSalgspris = aktuelSalgspris;
  }


  public   void   connect (Varesalg varesalg)
  {  
    this.totalVaresalgKvantum = this.totalVaresalgKvantum + varesalg.getKvantum();
    this.varesalgsVector.add(varesalg);
  }
  public   void   disconnect (Varesalg varesalg)
  {  
    this.varesalgsVector.remove(varesalg);
    this.totalVaresalgKvantum = this.totalVaresalgKvantum - varesalg.getKvantum();
  }

  public   int  getAntalVaresalg ()
  {  return varesalgsVector.size();   }

  public   Varesalg   getVaresalg ( int index )
  {  return  (Varesalg)varesalgsVector.get(index);   }

  public   Iterator   getVaresalgIterator ()
  {  return varesalgsVector.iterator();  } 

  // registrering af vare udget
  public   void   udgaa (Timestamp dato)
  {  
    this.udgaaetDato   = (Timestamp)dato.clone();
    this.tilstand      = TILSTAND_UDGAAET;
  }

  public   void   modtag ( Timestamp dato,double kvantum, double pris ) 
  { 
    this.sidstModtagetDato    = (Timestamp)dato.clone();
    this.sidstModtagetKvantum = kvantum;
    this.sidstModtagetPris    = pris;
    this.totalModtagetKvantum = this.totalModtagetKvantum + kvantum;
  }

  public   void  sletVareData ( )
  {  
    // ikke realiseret endnu
  }

  public   double   getLagerKvantum ( )
  {  
    return (double)(this.totalModtagetKvantum - this.totalVaresalgKvantum);
  }

}  